@@ -272,13 +272,20 @@ class DataFrame:
                             names = elements
                         else:
                             for i in range(len(elements)):
-                                try:
+                                if len(elements[i]) > 0:
+                                    if (elements[i][0] == "\"" and elements[i][len(elements[i])-1] == "\""):
+                                        elements[i] = elements[i][1:len(elements[i])-1]
+                                try:                                    
                                     columns[i].append(elements[i])
                                 except:
+                                    
                                     columns[i] = [elements[i]]
                             
                 else:
                     for i in range(len(elements)):
+                        if len(elements[i]) > 0:
+                            if (elements[i][0] == "\"" and elements[i][len(elements[i])-1] == "\""):
+                                elements[i] = elements[i][1:len(elements[i])-1]
                         try:
                             columns[i].append(elements[i])
                         except:
